@@ -1,12 +1,9 @@
-# type: ignore
 """
 Template engine for parameterizing GitHub templates and other configuration files.
 
 Supports Jinja2-style templating with variable substitution and conditional sections.
 Enables users to customize MoAI-ADK templates for their own projects.
 
-@TAG:TEMPLATE-ENGINE-001 - Template variable substitution system
-@TAG:GITHUB-CUSTOMIZATION-001 - GitHub template parameterization
 """
 
 from pathlib import Path
@@ -19,6 +16,7 @@ from jinja2 import (
     TemplateNotFound,
     TemplateRuntimeError,
     TemplateSyntaxError,
+    Undefined,
 )
 
 
@@ -45,13 +43,9 @@ class TemplateEngine:
             Variables must be explicitly provided to avoid silent template failures.
         """
         self.strict_undefined = strict_undefined
-        self.undefined_behavior = StrictUndefined if strict_undefined else None
+        self.undefined_behavior = StrictUndefined if strict_undefined else Undefined
 
-    def render_string(
-        self,
-        template_string: str,
-        variables: Dict[str, Any]
-    ) -> str:
+    def render_string(self, template_string: str, variables: Dict[str, Any]) -> str:
         """
         Render a Jinja2 template string with provided variables.
 
@@ -70,7 +64,7 @@ class TemplateEngine:
             env = Environment(
                 undefined=self.undefined_behavior,
                 trim_blocks=False,
-                lstrip_blocks=False
+                lstrip_blocks=False,
             )
             template = env.from_string(template_string)
             return template.render(**variables)
@@ -81,7 +75,7 @@ class TemplateEngine:
         self,
         template_path: Path,
         variables: Dict[str, Any],
-        output_path: Optional[Path] = None
+        output_path: Optional[Path] = None,
     ) -> str:
         """
         Render a Jinja2 template file with provided variables.
@@ -110,18 +104,20 @@ class TemplateEngine:
                 loader=FileSystemLoader(str(template_dir)),
                 undefined=self.undefined_behavior,
                 trim_blocks=False,
-                lstrip_blocks=False
+                lstrip_blocks=False,
             )
             template = env.get_template(template_name)
             rendered = template.render(**variables)
 
             if output_path:
                 output_path.parent.mkdir(parents=True, exist_ok=True)
-                output_path.write_text(rendered, encoding='utf-8')
+                output_path.write_text(rendered, encoding="utf-8")
 
             return rendered
         except TemplateNotFound:
-            raise FileNotFoundError(f"Template not found in {template_dir}: {template_name}")
+            raise FileNotFoundError(
+                f"Template not found in {template_dir}: {template_name}"
+            )
         except (TemplateSyntaxError, TemplateRuntimeError) as e:
             raise RuntimeError(f"Template rendering error in {template_path}: {e}")
 
@@ -130,7 +126,7 @@ class TemplateEngine:
         template_dir: Path,
         output_dir: Path,
         variables: Dict[str, Any],
-        pattern: str = "**/*.{md,yml,yaml,json}"
+        pattern: str = "**/*",
     ) -> Dict[str, str]:
         """
         Render all template files in a directory.
@@ -139,7 +135,7 @@ class TemplateEngine:
             template_dir: Source directory containing templates
             output_dir: Destination directory for rendered files
             variables: Dictionary of variables to substitute
-            pattern: Glob pattern for files to process (default: template files)
+            pattern: Glob pattern for files to process (default: all files)
 
         Returns:
             Dictionary mapping input paths to rendered content
@@ -172,34 +168,41 @@ class TemplateEngine:
         Extract template variables from project configuration.
 
         Args:
-            config: Project configuration dictionary (from .moai/config.json)
+            config: Project configuration dictionary (from .moai/config/config.json)
 
         Returns:
             Dictionary of template variables
         """
         github_config = config.get("github", {}).get("templates", {})
         project_config = config.get("project", {})
+        user_config = config.get("user", {})
 
         return {
             # Project information
             "PROJECT_NAME": project_config.get("name", "MyProject"),
             "PROJECT_DESCRIPTION": project_config.get("description", ""),
+            "PROJECT_OWNER": project_config.get("owner", ""),
             "PROJECT_MODE": project_config.get("mode", "team"),  # team or personal
-
+            "CODEBASE_LANGUAGE": project_config.get("codebase_language", "python"),
+            # User information
+            "USER_NAME": user_config.get("name", ""),
             # Directory structure
             "SPEC_DIR": github_config.get("spec_directory", ".moai/specs"),
             "DOCS_DIR": github_config.get("docs_directory", ".moai/docs"),
             "TEST_DIR": github_config.get("test_directory", "tests"),
-
             # Feature flags
             "ENABLE_TRUST_5": github_config.get("enable_trust_5", True),
-            "ENABLE_TAG_SYSTEM": github_config.get("enable_tag_system", True),
             "ENABLE_ALFRED_COMMANDS": github_config.get("enable_alfred_commands", True),
-
             # Language configuration
-            "CONVERSATION_LANGUAGE": project_config.get("conversation_language", "en"),
-            "CONVERSATION_LANGUAGE_NAME": project_config.get("conversation_language_name", "English"),
-
+            "CONVERSATION_LANGUAGE": config.get("language", {}).get(
+                "conversation_language", "en"
+            ),
+            "CONVERSATION_LANGUAGE_NAME": config.get("language", {}).get(
+                "conversation_language_name", "English"
+            ),
+            "AGENT_PROMPT_LANGUAGE": config.get("language", {}).get(
+                "agent_prompt_language", "english"
+            ),
             # Additional metadata
             "MOAI_VERSION": config.get("moai", {}).get("version", "0.7.0"),
         }
@@ -213,19 +216,22 @@ class TemplateVariableValidator:
 
     REQUIRED_VARIABLES = {
         "PROJECT_NAME": str,
+        "PROJECT_OWNER": str,
+        "CODEBASE_LANGUAGE": str,
         "SPEC_DIR": str,
         "DOCS_DIR": str,
         "TEST_DIR": str,
+        "CONVERSATION_LANGUAGE": str,
     }
 
-    OPTIONAL_VARIABLES = {
+    OPTIONAL_VARIABLES: Dict[str, Any] = {
         "PROJECT_DESCRIPTION": (str, type(None)),
         "PROJECT_MODE": str,
         "ENABLE_TRUST_5": bool,
-        "ENABLE_TAG_SYSTEM": bool,
         "ENABLE_ALFRED_COMMANDS": bool,
         "CONVERSATION_LANGUAGE": str,
         "CONVERSATION_LANGUAGE_NAME": str,
+        "USER_NAME": (str, type(None)),
     }
 
     @classmethod
@@ -257,9 +263,11 @@ class TemplateVariableValidator:
             if var_name in variables:
                 if not isinstance(variables[var_name], var_type):
                     if isinstance(var_type, tuple):
-                        type_names = " or ".join(t.__name__ for t in var_type)
+                        type_names = " or ".join(
+                            getattr(t, "__name__", str(t)) for t in var_type
+                        )
                     else:
-                        type_names = var_type.__name__
+                        type_names = getattr(var_type, "__name__", str(var_type))
                     actual_type = type(variables[var_name]).__name__
                     errors.append(
                         f"Invalid type for {var_name}: "
